@@ -8,7 +8,7 @@
   \author  M. Gastineau
            Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
 
-   Copyright, 2011-2021,  CNRS
+   Copyright, 2011-2024,  CNRS
    email of the author : Mickael.Gastineau@obspm.fr
 
   History:
@@ -136,6 +136,8 @@ struct SPICEkernel *calceph_spice_addfile(struct calcephbin_spice *eph)
 {
     struct SPICEkernel *prec = NULL, *pnew;
 
+    buffer_error_t buffer_error;
+
     if (eph->list == NULL)
     {
         eph->AU = 0.E0;
@@ -175,8 +177,11 @@ struct SPICEkernel *calceph_spice_addfile(struct calcephbin_spice *eph)
     pnew = (struct SPICEkernel *) malloc(sizeof(struct SPICEkernel));
     if (pnew == NULL)
     {
-        fatalerror("Can't allocate memory for SPICEkernel\nSystem error : '%s'\n", strerror(errno));
+        /* GCOVR_EXCL_START */
+        fatalerror("Can't allocate memory for SPICEkernel\nSystem error : '%s'\n",
+                   calceph_strerror_errno(buffer_error));
         return NULL;
+        /* GCOVR_EXCL_STOP */
     }
     /* add it to the tail */
     pnew->next = NULL;
@@ -580,7 +585,7 @@ int calceph_spice_getconstant_vd(const struct calcephbin_spice *eph, const char
   @param name (in) constant name
 */
 /*--------------------------------------------------------------------------*/
-static struct TXTPCKconstant *calceph_spicekernel_getptrconstant(struct SPICEkernel *eph, const char *name)
+const struct TXTPCKconstant *calceph_spicekernel_getptrconstant(struct SPICEkernel *eph, const char *name)
 {
     struct TXTPCKconstant *found = NULL;
 
@@ -609,7 +614,7 @@ static struct TXTPCKconstant *calceph_spicekernel_getptrconstant(struct SPICEker
 /*--------------------------------------------------------------------------*/
 static const struct TXTPCKconstant *calceph_spice_getptrconstant(const struct calcephbin_spice *eph, const char *name)
 {
-    struct TXTPCKconstant *found = NULL;
+    const struct TXTPCKconstant *found = NULL;
 
     struct SPICEkernel *list = eph->list;
 
@@ -1293,13 +1298,14 @@ static int calceph_spice_computeframe_matrix(const struct calcephbin_spice *eph,
                     res = calceph_spice_computeframe_matrix(eph, NULL, relativeframe, center, JD0,
                                                             time, matrixrelative, unitmatrix, idfixed);
 
-                    calceph_matrix3x3_prod(matrix,  matrixframe, matrixrelative);
+                    calceph_matrix3x3_prod(matrix, matrixframe, matrixrelative);
                     *unitmatrix = 0;
                 }
             }
-           
+
 #if DEBUG
-            printf("calceph_spice_computeframe_matrix - tkframe_relative: %p relativeframe : %p \n", fkframe->tkframe_relative, relativeframe);
+            printf("calceph_spice_computeframe_matrix - tkframe_relative: %p relativeframe : %p \n",
+                   fkframe->tkframe_relative, relativeframe);
 #endif
         }
     }
@@ -1434,7 +1440,6 @@ int calceph_spice_orient_unit(struct calcephbin_spice *eph, double JD0, double t
 
     const struct TXTFKframe *firstframe = NULL;
 
-    
     if ((unit & CALCEPH_USE_NAIFID) == 0)
     {
         newunit = unit + CALCEPH_USE_NAIFID;
@@ -1443,10 +1448,9 @@ int calceph_spice_orient_unit(struct calcephbin_spice *eph, double JD0, double t
             fatalerror("Orientation for the target object %d is not supported.\n", target);
             return 0;
         }
-         target = NAIFID_MOON;
+        target = NAIFID_MOON;
     }
-    
-    
+
     if ((newunit & CALCEPH_USE_NAIFID) != 0)
     {
         int *countlisttime;
@@ -1494,7 +1498,7 @@ int calceph_spice_orient_unit(struct calcephbin_spice *eph, double JD0, double t
             return calceph_txtpck_orient_unit(eph, JD0, time, target, newunit, order, PV);
         }
     }
-    
+
     if (target_spiceid == -1)
     {
         fatalerror("Orientation for the target object %d is not available in the ephemeris file.\n", target);
