@@ -148,6 +148,8 @@ static void calceph_txtfk_debug(const struct TXTFKfile *header)
 /*--------------------------------------------------------------------------*/
 int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale clocale, struct SPICEkernel *res)
 {
+    buffer_error_t buffer_error;
+
     off_t lenfile;
 
     size_t ulenfile;
@@ -183,14 +185,17 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
     /* go to the end of the file */
     if (fseeko(file, 0L, SEEK_END) != 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't jump to the end of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
-                   strerror(errno));
+                   calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     lenfile = ftello(file);
     if (lenfile < 0)
     {
-        fatalerror("Can't get the size of the ephemeris file '%s'\nSystem error : '%s'\n", filename, strerror(errno));
+        fatalerror("Can't get the size of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
+                   calceph_strerror_errno(buffer_error));
         return 0;
     }
     /* allocate memory */
@@ -198,9 +203,11 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
     buffer = (char *) malloc(sizeof(char) * (size_t) lenfile);
     if (buffer == NULL)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                   (unsigned long) (sizeof(char) * (size_t) lenfile), strerror(errno));
+                   (unsigned long) (sizeof(char) * (size_t) lenfile), calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     buffer[lenfile - 1] = '\0';
 
@@ -208,7 +215,7 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
     if (fseeko(file, 0L, SEEK_SET) != 0)
     {
         fatalerror("Can't jump to the end of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
-                   strerror(errno));
+                   calceph_strerror_errno(buffer_error));
         return 0;
     }
     /* printf("lenfile=%d\n", (int) lenfile); */
@@ -216,14 +223,15 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
     ulenfile = (size_t) lenfile;
     if (fread(buffer, sizeof(char), ulenfile, file) != ulenfile)
     {
-        fatalerror("Can't read the ephemeris file '%s'\nSystem error : '%s'\n", filename, strerror(errno));
+        fatalerror("Can't read the ephemeris file '%s'\nSystem error : '%s'\n", filename,
+                   calceph_strerror_errno(buffer_error));
         return 0;
     }
     /* check the header  */
     if (lenfile < 6 || strncmp(buffer, "KPL/FK", 6) != 0)
     {
         fatalerror("Can't read the header of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
-                   strerror(errno));
+                   calceph_strerror_errno(buffer_error));
         return 0;
     }
   /*---------------------------------------------------------*/
@@ -239,15 +247,15 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
         {
             /* printf("enter in a  data section : '%.50s'\n", buffer + curpos); */
             curpos += lenbegindata;
-            /* to skip \begindata inside a text ssection */
-            while (curpos < lenfile && buffer[curpos] != '\n' && buffer[curpos] != '\r' && isspace(buffer[curpos]))
+            /* to skip \begindata inside a text section */
+            while (curpos < lenfile && buffer[curpos] != '\n' && buffer[curpos] != '\r' && isspace_char(buffer[curpos]))
                 curpos++;
             if (buffer[curpos] != '\n' && buffer[curpos] != '\r')
                 continue;
 
             while (curpos < lenfile && buffer[curpos] != '\\')
             {
-                while (curpos < lenfile && isspace(buffer[curpos]))
+                while (curpos < lenfile && isspace_char(buffer[curpos]))
                     curpos++;
                 if (curpos < lenfile && buffer[curpos] != '\\')
                 {
@@ -255,28 +263,29 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
 
                     struct TXTPCKvalue *listvalue = NULL, *prec = NULL;
 
-                    /* read the keyword */
+                    /* read the keyword : 
+                       contain any characters except : tab, space, comma, parenthese, equal */
                     off_t begkeyword = curpos;
 
                     off_t endkeyword;
 
                     off_t begvalue, endvalue;
 
-                    while (curpos < lenfile && !isspace(buffer[curpos]) && buffer[curpos] != '='
-                           && buffer[curpos] != '+')
+                    while (curpos < lenfile && !isspace_char(buffer[curpos]) && buffer[curpos] != '='
+                           && buffer[curpos] != ',' && buffer[curpos] != '(')
                         curpos++;
                     endkeyword = curpos;
                     /* printf("keyword= %d %d '%.*s'\n", (int) begkeyword, (int) endkeyword, (int) (endkeyword -
                      * begkeyword), buffer + begkeyword); */
                     while (curpos < lenfile
-                           && (isspace(buffer[curpos]) || buffer[curpos] == '=' || buffer[curpos] == '+'))
+                           && (isspace_char(buffer[curpos]) || buffer[curpos] == '=' || buffer[curpos] == '+'))
                         curpos++;
 
                     /* find the ( */
-                    while (curpos < lenfile && isspace(buffer[curpos]))
+                    while (curpos < lenfile && isspace_char(buffer[curpos]))
                         curpos++;
                     /* check the parenthesis */
-                    if (buffer[curpos] != '(' && buffer[curpos] != '\'' && !isdigit(buffer[curpos])
+                    if (buffer[curpos] != '(' && buffer[curpos] != '\'' && !isdigit_char(buffer[curpos])
                         && buffer[curpos] != '-')
                     {
                         fatalerror("Can't find  the character '(' or '  or a digit after the keyword '%.*s'\n",
@@ -296,9 +305,12 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                         listvalue = (struct TXTPCKvalue *) malloc(sizeof(struct TXTPCKvalue));
                         if (listvalue == NULL)
                         {
+                            /* GCOVR_EXCL_START */
                             fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                       (unsigned long) (sizeof(struct TXTPCKvalue)), strerror(errno));
+                                       (unsigned long) (sizeof(struct TXTPCKvalue)),
+                                       calceph_strerror_errno(buffer_error));
                             return 0;
+                            /* GCOVR_EXCL_STOP */
                         }
                         listvalue->next = NULL;
                         listvalue->buffer = buffer;
@@ -313,7 +325,7 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                             struct TXTPCKvalue *pnewval;
 
                             /* read the value */
-                            while (curpos < lenfile && isspace(buffer[curpos]))
+                            while (curpos < lenfile && isspace_char(buffer[curpos]))
                                 curpos++;
                             begvalue = curpos;
 
@@ -329,7 +341,7 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                             {   /* begin a value */
                                 off_t k;
 
-                                while (curpos < lenfile && !isspace(buffer[curpos]) && buffer[curpos] != ','
+                                while (curpos < lenfile && !isspace_char(buffer[curpos]) && buffer[curpos] != ','
                                        && buffer[curpos] != ')')
                                 {
                                     curpos++;
@@ -347,9 +359,12 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                             pnewval = (struct TXTPCKvalue *) malloc(sizeof(struct TXTPCKvalue));
                             if (pnewval == NULL)
                             {
+                                /* GCOVR_EXCL_START */
                                 fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                           (unsigned long) (sizeof(struct TXTPCKvalue)), strerror(errno));
+                                           (unsigned long) (sizeof(struct TXTPCKvalue)),
+                                           calceph_strerror_errno(buffer_error));
                                 return 0;
+                                /* GCOVR_EXCL_STOP */
                             }
                             pnewval->next = NULL;
                             pnewval->buffer = buffer;
@@ -364,7 +379,7 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                             }
 
                             /* find the ) or , */
-                            while (curpos < lenfile && isspace(buffer[curpos]))
+                            while (curpos < lenfile && isspace_char(buffer[curpos]))
                                 curpos++;
 
                             if (curpos < lenfile && buffer[curpos] == ',')
@@ -377,7 +392,7 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                     {
                         begvalue = curpos;
                         curpos++;
-                        while (curpos < lenfile && !isspace(buffer[curpos]))
+                        while (curpos < lenfile && !isspace_char(buffer[curpos]))
                             curpos++;
                         curpos++;
                         endvalue = curpos;
@@ -386,7 +401,8 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                         if (listvalue == NULL)
                         {
                             fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                       (unsigned long) (sizeof(struct TXTPCKvalue)), strerror(errno));
+                                       (unsigned long) (sizeof(struct TXTPCKvalue)),
+                                       calceph_strerror_errno(buffer_error));
                             return 0;
                         }
                         listvalue->next = NULL;
@@ -399,9 +415,12 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                     pnewcst = (struct TXTPCKconstant *) malloc(sizeof(struct TXTPCKconstant));
                     if (pnewcst == NULL)
                     {
+                        /* GCOVR_EXCL_START */
                         fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                   (unsigned long) (sizeof(struct TXTPCKconstant)), strerror(errno));
+                                   (unsigned long) (sizeof(struct TXTPCKconstant)),
+                                   calceph_strerror_errno(buffer_error));
                         return 0;
+                        /* GCOVR_EXCL_STOP */
                     }
                     pnewcst->next = NULL;
                     pnewcst->value = listvalue;
@@ -409,9 +428,12 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                     pnewcst->name = (char *) malloc(((size_t) (endkeyword - begkeyword + 1)) * sizeof(char));
                     if (pnewcst->name == NULL)
                     {
+                        /* GCOVR_EXCL_START */
                         fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                   (unsigned long) (sizeof(endkeyword - begkeyword + 1)), strerror(errno));
+                                   (unsigned long) (sizeof(endkeyword - begkeyword + 1)),
+                                   calceph_strerror_errno(buffer_error));
                         return 0;
+                        /* GCOVR_EXCL_STOP */
                     }
                     memcpy(pnewcst->name, buffer + begkeyword, (endkeyword - begkeyword) * sizeof(char));
                     pnewcst->name[endkeyword - begkeyword] = '\0';
@@ -455,9 +477,11 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
             newframe = (struct TXTFKframe *) malloc(sizeof(struct TXTFKframe));
             if (newframe == NULL)
             {
-                fatalerror("Can't allocate memory for %d bytes\n", (int)sizeof(struct TXTFKframe));
+                /* GCOVR_EXCL_START */
+                fatalerror("Can't allocate memory for %d bytes\n", (int) sizeof(struct TXTFKframe));
                 calceph_txtpck_close(&res->filedata.txtfk.txtpckfile);
                 return 0;
+                /* GCOVR_EXCL_STOP */
             }
             /* find the TK frame */
             newframe->tkframe_relative = NULL;
@@ -517,7 +541,6 @@ int calceph_txtfk_open(FILE * file, const char *filename, struct calceph_locale
                 return 0;
             }
 
-
             sprintf(consttmpname, "TKFRAME_%d_RELATIVE", newframe->frame_id);
             if (calceph_txtpck_getconstant_txtpckvalue(&res->filedata.txtfk.txtpckfile, consttmpname,
                                                        &newframe->tkframe_relative))
@@ -940,6 +963,6 @@ int calceph_txtfk_createeulerangles_matrix(double tkframe_angles[3], double tkfr
     tkframe_angles[0] = psi;
     tkframe_angles[1] = theta;
     tkframe_angles[2] = phi;
-    
+
     return 1;
 }
