@@ -100,11 +100,9 @@ static int calceph_txtpck_getconstant_intmatrixnxn(struct TXTPCKfile *eph, const
                                                    int n2, int *p_pival);
 static int calceph_txtpck_getconstant_matrixnxn(struct TXTPCKfile *eph, const char *name, int n1, int n2,
                                                 double *p_pdval);
-static double calceph_strtod(const char *nptr, char **endptr, struct calceph_locale clocale);
 
 static struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile, off_t begkeyword,
-                                                           off_t endkeyword, const char *filename,
-                                                           off_t * pcurpos);
+                                                           off_t endkeyword, const char *filename, off_t * pcurpos);
 static void calceph_txtpck_load_appendvaluetoend(struct TXTPCKconstant *pnewcst, struct TXTPCKvalue *listvalue);
 
 #if DEBUG
@@ -199,7 +197,9 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
 
     const size_t lenheader = strlen(header);
 
-  /*---------------------------------------------------------*/
+    buffer_error_t buffer_error;
+
+    /*---------------------------------------------------------*/
     /* initialize with empty values if a failure occurs during the initialization */
     /*---------------------------------------------------------*/
     res->listconstant = NULL;
@@ -212,51 +212,65 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
     /* go to the end of the file */
     if (fseeko(file, 0L, SEEK_END) != 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't jump to the end of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
-                   strerror(errno));
+                   calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     lenfile = ftello(file);
     if (lenfile < 0)
     {
-        fatalerror("Can't get the size of the ephemeris file '%s'\nSystem error : '%s'\n", filename, strerror(errno));
+        /* GCOVR_EXCL_START */
+        fatalerror("Can't get the size of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
+                   calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     /* allocate memory */
     lenfile++;
     buffer = (char *) malloc(sizeof(char) * (size_t) lenfile);
     if (buffer == NULL)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                   (unsigned long) (sizeof(char) * (size_t) lenfile), strerror(errno));
+                   (unsigned long) (sizeof(char) * (size_t) lenfile), calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     buffer[lenfile - 1] = '\0';
 
     /* read the file  */
     if (fseeko(file, 0L, SEEK_SET) != 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't jump to the end of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
-                   strerror(errno));
+                   calceph_strerror_errno(buffer_error));
         free(buffer);
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     /* printf("lenfile=%d\n", (int) lenfile); */
     lenfile--;
     ulenfile = (size_t) lenfile;
     if (fread(buffer, sizeof(char), ulenfile, file) != ulenfile)
     {
-        fatalerror("Can't read the ephemeris file '%s'\nSystem error : '%s'\n", filename, strerror(errno));
+        /* GCOVR_EXCL_START */
+        fatalerror("Can't read the ephemeris file '%s'\nSystem error : '%s'\n", filename,
+                   calceph_strerror_errno(buffer_error));
         free(buffer);
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     /* check the header  */
     if (ulenfile < lenheader || strncmp(buffer, header, lenheader) != 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't read the header of the ephemeris file '%s'\nSystem error : '%s'\n", filename,
-                   strerror(errno));
+                   calceph_strerror_errno(buffer_error));
         free(buffer);
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     /*---------------------------------------------------------*/
     /* loop until the end of file to read the constant */
@@ -271,15 +285,15 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
         {
             /* printf("enter in a  data section : '%.50s'\n", buffer + curpos); */
             curpos += lenbegindata;
-            /* to skip \begindata inside a text ssection */
-            while (curpos < lenfile && buffer[curpos] != '\n' && buffer[curpos] != '\r' && isspace(buffer[curpos]))
+            /* to skip \begindata inside a text section */
+            while (curpos < lenfile && buffer[curpos] != '\n' && buffer[curpos] != '\r' && isspace_char(buffer[curpos]))
                 curpos++;
             if (buffer[curpos] != '\n' && buffer[curpos] != '\r')
                 continue;
 
             while (curpos < lenfile && buffer[curpos] != '\\')
             {
-                while (curpos < lenfile && isspace(buffer[curpos]))
+                while (curpos < lenfile && isspace_char(buffer[curpos]))
                     curpos++;
                 if (curpos < lenfile && buffer[curpos] != '\\')
                 {
@@ -295,14 +309,14 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
 
                     size_t sizekeyword; /* in characters */
 
-                    while (curpos < lenfile && !isspace(buffer[curpos]) && buffer[curpos] != '=')
+                    while (curpos < lenfile && !isspace_char(buffer[curpos]) && buffer[curpos] != '=')
                         curpos++;
                     endkeyword = curpos;
                     sizekeyword = endkeyword - begkeyword;
                     /* printf("keyword= %d %d '%.*s'\n", (int) begkeyword, (int) endkeyword, (int) (endkeyword -
                      * begkeyword), buffer + begkeyword); */
 
-                    while (curpos < lenfile && isspace(buffer[curpos]))
+                    while (curpos < lenfile && isspace_char(buffer[curpos]))
                         curpos++;
                     if (curpos + 1 < lenfile)
                     {
@@ -318,9 +332,11 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
                         }
                         else
                         {
+                            /* GCOVR_EXCL_START */
                             fatalerror("The file '%s' is malformed\n", filename);
                             free(buffer);
                             return 0;
+                            /* GCOVR_EXCL_STOP */
                         }
                     }
 
@@ -354,10 +370,13 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
                         pnewcst = (struct TXTPCKconstant *) malloc(sizeof(struct TXTPCKconstant));
                         if (pnewcst == NULL)
                         {
+                            /* GCOVR_EXCL_START */
                             fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                       (unsigned long) (sizeof(struct TXTPCKconstant)), strerror(errno));
+                                       (unsigned long) (sizeof(struct TXTPCKconstant)),
+                                       calceph_strerror_errno(buffer_error));
                             free(buffer);
                             return 0;
+                            /* GCOVR_EXCL_STOP */
                         }
                         pnewcst->next = NULL;
                         pnewcst->value = listvalue;
@@ -365,10 +384,12 @@ int calceph_txtpck_load(FILE * file, const char *filename, const char *header,
                         pnewcst->name = (char *) malloc((sizekeyword + 1) * sizeof(char));
                         if (pnewcst->name == NULL)
                         {
+                            /* GCOVR_EXCL_START */
                             fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                                       (unsigned long) (sizeof(sizekeyword + 1)), strerror(errno));
+                                       (unsigned long) (sizeof(sizekeyword + 1)), calceph_strerror_errno(buffer_error));
                             free(buffer);
                             return 0;
+                            /* GCOVR_EXCL_STOP */
                         }
                         memcpy(pnewcst->name, buffer + begkeyword, sizekeyword * sizeof(char));
                         pnewcst->name[endkeyword - begkeyword] = '\0';
@@ -447,16 +468,20 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
     struct TXTPCKvalue *listvalue = NULL, *prec = NULL;
     off_t begvalue, endvalue;
 
+    buffer_error_t buffer_error;
+
     /* find the ( or ' or digit or sign +- */
-    while (curpos < lenfile && isspace(buffer[curpos]))
+    while (curpos < lenfile && isspace_char(buffer[curpos]))
         curpos++;
     /* check the parenthesis or ' or digit or sign +- */
-    if (buffer[curpos] != '(' && buffer[curpos] != '\'' && !isdigit(buffer[curpos])
+    if (buffer[curpos] != '(' && buffer[curpos] != '\'' && !isdigit_char(buffer[curpos])
         && buffer[curpos] != '+' && buffer[curpos] != '-')
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't find  the character '(' , ' or a digit after the keyword '%.*s'\n",
                    endkeyword - begkeyword, buffer + begkeyword);
         return NULL;
+        /* GCOVR_EXCL_STOP */
     }
     /* single string */
     if (buffer[curpos] == '\'')
@@ -471,9 +496,11 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
         listvalue = (struct TXTPCKvalue *) malloc(sizeof(struct TXTPCKvalue));
         if (listvalue == NULL)
         {
+            /* GCOVR_EXCL_START */
             fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                       (unsigned long) (sizeof(struct TXTPCKvalue)), strerror(errno));
+                       (unsigned long) (sizeof(struct TXTPCKvalue)), calceph_strerror_errno(buffer_error));
             return NULL;
+            /* GCOVR_EXCL_STOP */
         }
         listvalue->next = NULL;
         listvalue->buffer = buffer;
@@ -488,7 +515,7 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
             struct TXTPCKvalue *pnewval;
 
             /* read the value */
-            while (curpos < lenfile && isspace(buffer[curpos]))
+            while (curpos < lenfile && isspace_char(buffer[curpos]))
                 curpos++;
             begvalue = curpos;
 
@@ -510,7 +537,8 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
             {                   /* begin a value */
                 off_t k;
 
-                while (curpos < lenfile && !isspace(buffer[curpos]) && buffer[curpos] != ',' && buffer[curpos] != ')')
+                while (curpos < lenfile && !isspace_char(buffer[curpos]) && buffer[curpos] != ','
+                       && buffer[curpos] != ')')
                 {
                     curpos++;
                 }
@@ -527,9 +555,11 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
             pnewval = (struct TXTPCKvalue *) malloc(sizeof(struct TXTPCKvalue));
             if (pnewval == NULL)
             {
+                /* GCOVR_EXCL_START */
                 fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                           (unsigned long) (sizeof(struct TXTPCKvalue)), strerror(errno));
+                           (unsigned long) (sizeof(struct TXTPCKvalue)), calceph_strerror_errno(buffer_error));
                 return NULL;
+                /* GCOVR_EXCL_STOP */
             }
             pnewval->next = NULL;
             pnewval->buffer = buffer;
@@ -544,7 +574,7 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
             }
 
             /* find the ) or , */
-            while (curpos < lenfile && isspace(buffer[curpos]))
+            while (curpos < lenfile && isspace_char(buffer[curpos]))
                 curpos++;
 
             if (curpos < lenfile && buffer[curpos] == ',')
@@ -553,7 +583,7 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
         curpos++;               /* skip parenthesis */
     }
     /* digit case */
-    else if (isdigit(buffer[curpos]) || buffer[curpos] == '+' || buffer[curpos] == '-')
+    else if (isdigit_char(buffer[curpos]) || buffer[curpos] == '+' || buffer[curpos] == '-')
     {
         struct TXTPCKvalue *pnewval;
 
@@ -562,7 +592,7 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
         /* begin a value */
         begvalue = curpos;
         while (curpos < lenfile
-               && (isdigit(buffer[curpos]) || buffer[curpos] == '.' || buffer[curpos] == 'D'
+               && (isdigit_char(buffer[curpos]) || buffer[curpos] == '.' || buffer[curpos] == 'D'
                    || buffer[curpos] == 'd' || buffer[curpos] == 'E' || buffer[curpos] == '+' || buffer[curpos] == '-'))
         {
             curpos++;
@@ -579,9 +609,11 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
         pnewval = (struct TXTPCKvalue *) malloc(sizeof(struct TXTPCKvalue));
         if (pnewval == NULL)
         {
+            /* GCOVR_EXCL_START */
             fatalerror("Can't allocate memory for %lu bytes\nSystem error : '%s'\n",
-                       (unsigned long) (sizeof(struct TXTPCKvalue)), strerror(errno));
+                       (unsigned long) (sizeof(struct TXTPCKvalue)), calceph_strerror_errno(buffer_error));
             return NULL;
+            /* GCOVR_EXCL_STOP */
         }
         pnewval->next = NULL;
         pnewval->buffer = buffer;
@@ -597,7 +629,7 @@ struct TXTPCKvalue *calceph_txtpck_load_decodevalue(char *buffer, off_t lenfile,
     }
     else
     {
-        fatalerror("unknown value type  after the keyword '%.*s' in the file '%s'\n", 
+        fatalerror("unknown value type  after the keyword '%.*s' in the file '%s'\n",
                    endkeyword - begkeyword, buffer + begkeyword, filename);
         return NULL;
     }
@@ -639,8 +671,8 @@ void calceph_txtpck_close(struct TXTPCKfile *eph)
 
     if (eph->buffer)
         free(eph->buffer);
-        
-    eph->listconstant = NULL;    
+
+    eph->listconstant = NULL;
     eph->buffer = NULL;
 }
 
@@ -784,7 +816,7 @@ static int calceph_txtpck_getconstant_intmatrixnxn(struct TXTPCKfile *eph, const
 
                 p_pival[j] = (int) l;
 
-                found = (isspace(*perr) || *perr == ',')
+                found = (isspace_char(*perr) || *perr == ',')
                     && (((off_t) (perr - listvalue->buffer)) <= listvalue->loclast);
             }
             else
@@ -848,7 +880,7 @@ static int calceph_txtpck_getconstant_matrixnxn(struct TXTPCKfile *eph, const ch
                 char *perr;
 
                 p_pdval[j] = calceph_strtod(listvalue->buffer + listvalue->locfirst, &perr, eph->clocale);
-                found = (isspace(*perr) || *perr == ',')
+                found = (isspace_char(*perr) || *perr == ',')
                     && (((off_t) (perr - listvalue->buffer)) <= listvalue->loclast);
             }
             else
@@ -1112,7 +1144,7 @@ int calceph_txtpck_getvalue_char(struct TXTPCKvalue *listvalue, char *p_pszval)
   on enter, the array must have enough room.
 */
 /*--------------------------------------------------------------------------*/
-static double calceph_strtod(const char *nptr, char **endptr, struct calceph_locale clocale)
+double calceph_strtod(const char *nptr, char **endptr, struct calceph_locale clocale)
 {
 #if USE_STRTOD_L
     if (clocale.useclocale == 1)
@@ -1142,9 +1174,11 @@ int calceph_txtpck_merge_incrementalassignment(struct SPICEkernel *list, struct
 
     if (newkernel->filetype != TXT_PCK)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Internal error in calceph_txtpck_merge_incrementalassignment : type of the kernel "
                    "should be TXT_PCK");
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
 
     for (cur = newkernel->filedata.txtpck.listconstant; cur != NULL;)
